==> production-demo-20260209_092157.tar.gz: var/www/html/production-demo/var/tmp/twig/98/980b825ad64e2152d259a5c549bb71ea.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/LeadBundle/Event/PointsChangeEvent.php */
class __TwigTemplate_e84194a20cc6470faa5109d6fa6148a2 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\LeadBundle\\Event;

use Mautic\\CoreBundle\\Event\\CommonEvent;
use Mautic\\LeadBundle\\Entity\\Lead;

class PointsChangeEvent extends CommonEvent
{
    protected int \$old;

    protected int \$new;

    public function __construct(Lead &\$lead, \$old, \$new)
    {
        \$this->entity = &\$lead;
        \$this->old    = (int) \$old;
        \$this->new    = (int) \$new;
    }

    /**
     * Returns the Lead entity.
     *
     * @return Lead
     */
    public function getLead()
    {
        return \$this->entity;
    }

    /**
     * Returns the new points.
     */
    public function getNewPoints(): int
    {
        return \$this->new;
    }

    /**
     * Returns the old points.
     */
    public function getOldPoints(): int
    {
        return \$this->old;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/LeadBundle/Event/PointsChangeEvent.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/LeadBundle/Event/PointsChangeEvent.php", "/var/www/html/mauticGIT-Test/app/bundles/LeadBundle/Event/PointsChangeEvent.php");
    }
}

==> production-demo-20260214_152721.tar.gz: var/www/html/production-demo/var/tmp/twig/98/980b825ad64e2152d259a5c549bb71ea.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/LeadBundle/Event/PointsChangeEvent.php */
class __TwigTemplate_e84194a20cc6470faa5109d6fa6148a2 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\LeadBundle\\Event;

use Mautic\\CoreBundle\\Event\\CommonEvent;
use Mautic\\LeadBundle\\Entity\\Lead;

class PointsChangeEvent extends CommonEvent
{
    protected int \$old;

    protected int \$new;

    public function __construct(Lead &\$lead, \$old, \$new)
    {
        \$this->entity = &\$lead;
        \$this->old    = (int) \$old;
        \$this->new    = (int) \$new;
    }

    /**
     * Returns the Lead entity.
     *
     * @return Lead
     */
    public function getLead()
    {
        return \$this->entity;
    }

    /**
     * Returns the new points.
     */
    public function getNewPoints(): int
    {
        return \$this->new;
    }

    /**
     * Returns the old points.
     */
    public function getOldPoints(): int
    {
        return \$this->old;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/LeadBundle/Event/PointsChangeEvent.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/LeadBundle/Event/PointsChangeEvent.php", "/var/www/html/production-demo/app/bundles/LeadBundle/Event/PointsChangeEvent.php");
    }
}
